"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DictionariesService = void 0;
const axios_1 = require("@nestjs/axios");
const common_1 = require("@nestjs/common");
const config_1 = require("@nestjs/config");
const rest_wrapper_class_1 = require("../models/dtos/wrappers/rest-wrapper.class");
const rxjs_1 = require("rxjs");
const mongoose_1 = require("mongoose");
let DictionariesService = class DictionariesService {
    constructor(_httpService, _configService) {
        this._httpService = _httpService;
        this._configService = _configService;
        this._baseUrl = this._configService.getOrThrow('DL_DICTIONARIES__REST__BASE_URL');
    }
    async fetchById(id) {
        try {
            const endpoint = `${this._baseUrl}/v1/dictionaries/by-id/${id}`;
            const response$ = this._httpService.get(endpoint);
            const response = await (0, rxjs_1.firstValueFrom)(response$);
            if (response.data.errors) {
                throw new rest_wrapper_class_1.RESTError('dictionaries_api_error', response.data.errors);
            }
            if (!response.data || !response.data.result) {
                throw new rest_wrapper_class_1.RESTError('dictionaries_api_error', 'empty response');
            }
            if (response.data.result.data) {
                const result = Object.assign(Object.assign({}, response.data.result.data), { _id: new mongoose_1.Types.ObjectId(response.data.result.data._id) });
                return result;
            }
            else {
                return null;
            }
        }
        catch (e) {
            throw rest_wrapper_class_1.RESTError.createFromCatch(e, { keyword: 'unknown', debug: e });
        }
    }
    async fetchByKeyword(keyword) {
        try {
            const endpoint = `${this._baseUrl}/v1/dictionaries/by-keyword/${keyword}`;
            const response$ = this._httpService.get(endpoint);
            const response = await (0, rxjs_1.firstValueFrom)(response$);
            if (response.data.errors) {
                throw new rest_wrapper_class_1.RESTError('dictionaries_api_error', response.data.errors);
            }
            if (!response.data || !response.data.result) {
                throw new rest_wrapper_class_1.RESTError('dictionaries_api_error', 'empty response');
            }
            if (response.data.result.data) {
                const result = Object.assign(Object.assign({}, response.data.result.data), { _id: new mongoose_1.Types.ObjectId(response.data.result.data._id) });
                return result;
            }
            else {
                return null;
            }
        }
        catch (e) {
            throw rest_wrapper_class_1.RESTError.createFromCatch(e, { keyword: 'unknown', debug: e });
        }
    }
    async validateIds(ids) {
        try {
            const endpoint = `${this._baseUrl}/v1/dictionaries/validate/by-ids`;
            const requestBody = { data: { ids } };
            const response$ = this._httpService.post(endpoint, requestBody);
            const response = await (0, rxjs_1.firstValueFrom)(response$);
            if (response.data.errors) {
                throw new rest_wrapper_class_1.RESTError('dictionaries_api_error', response.data.errors);
            }
            if (!response.data || !response.data.result) {
                throw new rest_wrapper_class_1.RESTError('dictionaries_api_error', 'empty response');
            }
            const result = [];
            for (let item of response.data.result.data) {
                result.push(Object.assign(Object.assign({}, item), { _id: new mongoose_1.Types.ObjectId(item._id) }));
            }
            return result;
        }
        catch (e) {
            throw rest_wrapper_class_1.RESTError.createFromCatch(e, { keyword: 'unknown', debug: e });
        }
    }
};
exports.DictionariesService = DictionariesService;
exports.DictionariesService = DictionariesService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [axios_1.HttpService, config_1.ConfigService])
], DictionariesService);
//# sourceMappingURL=dictionaries.service.js.map