"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StorageService = void 0;
const common_1 = require("@nestjs/common");
const FormData = require("form-data");
const config_1 = require("@nestjs/config");
const axios_1 = require("axios");
const rest_wrapper_class_1 = require("../models/dtos/wrappers/rest-wrapper.class");
let StorageService = class StorageService {
    constructor(_configsService) {
        this._configsService = _configsService;
        this._storageApiUrl = this._configsService.getOrThrow('DL_STORAGE__REST__BASE_URL');
        this._accessToken = this._configsService.getOrThrow('DL_STORAGE__REST__ACCESS_TOKEN');
        this._bucketName = this._configsService.getOrThrow('DL_STORAGE__REST__BUCKET_NAME');
    }
    async upload(body, autoCommit) {
        const form = new FormData();
        form.append('file', body.file, {
            filename: body.fileName,
            contentType: body.mimeType,
            knownLength: body.size,
        });
        let url = `${this._storageApiUrl}/bucket/${this._bucketName}/upload`;
        if (autoCommit) {
            url += '?autoCommit=true';
        }
        const response = await axios_1.default.postForm(url, form, this._axiosStandardConfig);
        return this._handleAxiosResponse(response, 'upload_failed');
    }
    async download(fileId) {
        try {
            return axios_1.default.get(`${this._storageApiUrl}/bucket/${this._bucketName}/file/${fileId}/download`, this._axiosStreamConfig);
        }
        catch (error) {
            throw new rest_wrapper_class_1.RESTError('storage_error', error);
        }
    }
    async getMeta(fileId, bucketName) {
        const response = await axios_1.default.get(`${this._storageApiUrl}/bucket/${bucketName}/file/${fileId}/meta`, this._axiosStandardConfig);
        return this._handleAxiosResponse(response, 'get_meta_failed');
    }
    _handleAxiosResponse(response, errorKeyword) {
        var _a, _b;
        if ((response === null || response === void 0 ? void 0 : response.data) && ((_a = response.data) === null || _a === void 0 ? void 0 : _a.result) && ((_b = response.data.result) === null || _b === void 0 ? void 0 : _b.data)) {
            return response.data.result.data;
        }
        else {
            throw { error: { keyword: errorKeyword, debug: response.data } };
        }
    }
    get _axiosStandardConfig() {
        return {
            headers: {
                'X-Access-Token': this._accessToken,
            },
        };
    }
    get _axiosStreamConfig() {
        return {
            responseType: 'stream',
            headers: {
                'X-Access-Token': this._accessToken,
            },
        };
    }
};
exports.StorageService = StorageService;
exports.StorageService = StorageService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [config_1.ConfigService])
], StorageService);
//# sourceMappingURL=storage.service.js.map