"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toInt32 = exports.toBoolean = exports.toMongoIdArray = exports.toMongoId = exports.toStringArray = void 0;
const class_validator_1 = require("class-validator");
const mongoose_1 = require("mongoose");
const rest_wrapper_class_1 = require("../models/dtos/wrappers/rest-wrapper.class");
const toStringArray = (value) => {
    return typeof value === 'string' ? [value] : value;
};
exports.toStringArray = toStringArray;
const toMongoId = (value) => {
    const check = (0, class_validator_1.isMongoId)(value);
    if (!check) {
        throw new rest_wrapper_class_1.RESTError('invalid_mongoid', value);
    }
    return mongoose_1.Types.ObjectId.createFromHexString(value);
};
exports.toMongoId = toMongoId;
const toMongoIdArray = (values) => {
    const result = [];
    const items = typeof values === 'string' ? [values] : values;
    for (const value of items) {
        result.push(toMongoId(value));
    }
    return result;
};
exports.toMongoIdArray = toMongoIdArray;
const toBoolean = (value) => {
    return value === 'true';
};
exports.toBoolean = toBoolean;
const toInt32 = (value) => {
    const int64Min = -9223372036854775808;
    const int64Max = 9223372036854775807;
    const intValue = Number(value);
    if (isNaN(intValue)) {
        throw new rest_wrapper_class_1.RESTError('conversion_error', 'Invalid input: Not a number.');
    }
    if (!Number.isSafeInteger(intValue)) {
        throw new rest_wrapper_class_1.RESTError('conversion_error', 'Invalid input: Value exceeds safe integer limits.');
    }
    if (intValue < int64Min || intValue > int64Max) {
        throw new rest_wrapper_class_1.RESTError('conversion_error', 'Value is out of the 64-bit signed integer range.');
    }
    return intValue;
};
exports.toInt32 = toInt32;
//# sourceMappingURL=helper.utils.js.map