import { Schema, Prop, SchemaFactory } from '@nestjs/mongoose';
import { HydratedDocument } from 'mongoose';
import { IAttachement } from '../../interfaces/attachement.interface';
import { Identifable } from '../identifable.schema';
import { AttachementType } from '../../enums/attachement-type.enum';
import { IFileEmbedded } from '../../interfaces/s3.interface';
import { FileEmbeddedSchema } from './s3.schema';

@Schema({ _id: false })
export class Attachement extends Identifable implements IAttachement {
    @Prop({ required: true, enum: AttachementType, type: String })
    type: AttachementType;

    @Prop({ type: FileEmbeddedSchema, required: false, default: null })
    file: IFileEmbedded;

    @Prop({ type: String, required: false, default: null })
    link: string;
}

export const AttachementSchema = SchemaFactory.createForClass(Attachement);
export type AttachementDocument = HydratedDocument<Attachement>;
