import { Schema, Prop, SchemaFactory } from '@nestjs/mongoose';
import { IPerson } from '../../interfaces/person.interface';
import { HydratedDocument } from 'mongoose';
import { IResidence } from '../../interfaces/residence.interface';
import { Residence, ResidenceSchema } from './residence.schema';
import { DictionaryEmbeddedSchema } from './dictionary-embedded.schema';
import { IDictionary } from '../../interfaces/dictionary.interface';

@Schema({ _id: false })
export class Person implements IPerson {
    @Prop({ type: String, required: false, default: null })
    pid: string;

    @Prop({ type: String, required: true })
    firstName: string;

    @Prop({ type: String, required: true })
    lastName: string;

    @Prop({ type: Date, required: false, default: null })
    birthDate: Date;

    @Prop({ type: DictionaryEmbeddedSchema, required: false })
    gender: IDictionary;

    @Prop({ type: ResidenceSchema, required: true, default: () => new Residence() })
    residence: IResidence;
}

export const PersonSchema = SchemaFactory.createForClass(Person);
export type PersonDocument = HydratedDocument<Person>;
