import { Prop, Schema, SchemaFactory } from '@nestjs/mongoose';
import { HydratedDocument, mongo, SchemaTypes } from 'mongoose';
import { IFileEmbedded, IFileLog, IFileMeta, IFileRecord, IFileState, ILogInitiator, IS3, IS3File } from '../../interfaces/s3.interface';
import { FileLogInitType, S3FileState } from '../../enums/s3.enum';

@Schema({ _id: false })
export class S3 implements IS3 {
    @Prop({ type: String, required: true })
    key: string;

    @Prop({ type: String, required: true })
    bucket: string;

    @Prop({ type: String, required: false })
    etag: string;
}

@Schema({ _id: false })
export class LogInitiator implements ILogInitiator {
    @Prop({ type: String, enum: FileLogInitType, required: false })
    type: FileLogInitType;

    @Prop({ type: String, required: false })
    name: string;
}

@Schema()
export class FileLog implements IFileLog {
    @Prop({ type: Date, required: true })
    createdAt: Date;

    @Prop({ type: String, enum: S3FileState, required: true })
    value: S3FileState;

    @Prop({ type: LogInitiator, required: false })
    initiator: LogInitiator;
}

@Schema({ _id: false })
export class FileMeta implements IFileMeta {
    @Prop({ type: String, required: false })
    name: string;

    @Prop({ type: Number, required: true })
    size: number;

    @Prop({ type: String, required: true })
    mimeType: string;

    @Prop({ type: String, required: true })
    extension: string;
}

@Schema({ _id: false })
export class FileState implements IFileState {
    @Prop({ type: String, enum: S3FileState, required: true })
    value: S3FileState;

    @Prop({ type: [FileLog], required: true, default: [] })
    log: FileLog[];
}

@Schema({ _id: false })
export class FileRecord implements IFileRecord {
    @Prop({ type: Date, required: true })
    createdAt: Date;

    @Prop({ type: Date, required: false })
    updatedAt: Date;
}

@Schema({ _id: false })
export class S3File implements IS3File {
    @Prop({ type: SchemaTypes.ObjectId, required: true })
    id: mongo.ObjectId;

    @Prop({ type: FileMeta, required: true, default: null })
    fileMeta: FileMeta;

    @Prop({ type: FileState, required: true, default: null })
    state: FileState;

    @Prop({ type: S3, required: true, default: null })
    s3: S3;

    @Prop({ type: FileRecord, required: true })
    record: FileRecord;

    @Prop({ type: String, required: true })
    owner: string;
}

@Schema({ _id: false })
export class FileEmbedded implements IFileEmbedded {
    @Prop({ type: String, required: true })
    id: string;

    @Prop({ type: String, required: false })
    name: string;

    @Prop({ type: Number, required: true })
    size: number;

    @Prop({ type: String, required: true })
    mimeType: string;

    @Prop({ type: S3, required: true, default: null })
    s3: S3;

    @Prop({ type: Date, required: true })
    createdAt: Date;
}

export const S3Schema = SchemaFactory.createForClass(S3);
export const LogInitiatorSchema = SchemaFactory.createForClass(LogInitiator);
export const FileLogSchema = SchemaFactory.createForClass(FileLog);
export const FileMetaSchema = SchemaFactory.createForClass(FileMeta);
export const FileStateSchema = SchemaFactory.createForClass(FileState);
export const FileRecordSchema = SchemaFactory.createForClass(FileRecord);
export const S3FileSchema = SchemaFactory.createForClass(S3File);
export const FileEmbeddedSchema = SchemaFactory.createForClass(FileEmbedded);

export type S3Document = HydratedDocument<S3>;
export type LogInitiatorDocument = HydratedDocument<LogInitiator>;
export type FileLogDocument = HydratedDocument<FileLog>;
export type FileMetaDocument = HydratedDocument<FileMeta>;
export type FileStateDocument = HydratedDocument<FileState>;
export type FileRecordDocument = HydratedDocument<FileRecord>;
export type S3FileDocument = HydratedDocument<S3File>;
export type FileEmbeddedDocument = HydratedDocument<FileEmbedded>;
