import { Prop, Schema, SchemaFactory } from '@nestjs/mongoose';
import { HydratedDocument } from 'mongoose';
import { UserVerificationLevel } from '../../enums/user-verifiation-level.enum';
import { IContact } from '../../interfaces/contact.interface';
import { IPerson } from '../../interfaces/person.interface';
import { ISessionUser } from '../../interfaces/session-user.interface';
import { ContactSchema } from './contact.schema';
import { PersonSchema } from './person.schema';

@Schema({ id: false })
export class SessionUser implements ISessionUser {
    @Prop({ required: true, type: String })
    _id: string;

    @Prop({ required: true, type: String })
    username: string;

    @Prop({ type: PersonSchema, required: true })
    person: IPerson;

    @Prop({ type: [ContactSchema], required: true, default: [] })
    contacts: IContact[];

    @Prop({ type: [String], required: true, default: [] })
    permissions: string[];

    @Prop({ type: String, enum: UserVerificationLevel, required: true, default: UserVerificationLevel.None })
    verificationLevel: UserVerificationLevel;
}

export const SessionUserSchema = SchemaFactory.createForClass(SessionUser);
export type SessionUserDocument = HydratedDocument<SessionUser>;
