import { isMongoId } from 'class-validator';
import { Types } from 'mongoose';
import { RESTError } from '../models/dtos/wrappers/rest-wrapper.class';

const toStringArray = (value: string | string[]) => {
    return typeof value === 'string' ? [value] : value;
};

const toMongoId = (value: string) => {
    const check = isMongoId(value);
    if (!check) {
        throw new RESTError('invalid_mongoid', value);
    }
    return Types.ObjectId.createFromHexString(value);
};

const toMongoIdArray = (values: string | string[]) => {
    const result: Types.ObjectId[] = [];
    const items = typeof values === 'string' ? [values] : values;
    for (const value of items) {
        result.push(toMongoId(value));
    }
    return result;
};

const toBoolean = (value: string) => {
    return value === 'true';
};

const toInt32 = (value: string) => {
    const int64Min = -9223372036854775808; // Minimum 64-bit signed integer
    const int64Max = 9223372036854775807; // Maximum 64-bit signed integer

    const intValue = Number(value); // Convert the string to a Number

    if (isNaN(intValue)) {
        throw new RESTError('conversion_error', 'Invalid input: Not a number.');
    }

    if (!Number.isSafeInteger(intValue)) {
        throw new RESTError('conversion_error', 'Invalid input: Value exceeds safe integer limits.');
    }

    if (intValue < int64Min || intValue > int64Max) {
        throw new RESTError('conversion_error', 'Value is out of the 64-bit signed integer range.');
    }

    return intValue;
};

export { toStringArray, toMongoId, toMongoIdArray, toBoolean, toInt32 };
